# coding: utf-8

# flake8: noqa
"""
    Collibra Catalog Classification API

    Version 2 of the Catalog Classification API offers functionality related to the classification process and facilitates searching for and managing the associations between a data class and a data category. Use version 1 of the API for managing classifications and legacy data classes.   # noqa: E501

    OpenAPI spec version: 2.0.0-unstable
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

# import models into model package
from collibra_catalog_classification.models.classification import Classification
from collibra_catalog_classification.models.classification_process_request import ClassificationProcessRequest
from collibra_catalog_classification.models.classification_process_response import ClassificationProcessResponse
from collibra_catalog_classification.models.data_class_data_category_connection import DataClassDataCategoryConnection
from collibra_catalog_classification.models.data_class_data_category_connections_paged_response import DataClassDataCategoryConnectionsPagedResponse
from collibra_catalog_classification.models.named_resource_reference_impl import NamedResourceReferenceImpl
from collibra_catalog_classification.models.resource_type import ResourceType
from collibra_catalog_classification.models.standard_error_response import StandardErrorResponse
