# coding: utf-8

"""
    Collibra Catalog Classification API

    Version 2 of the Catalog Classification API offers functionality related to the classification process and facilitates searching for and managing the associations between a data class and a data category. Use version 1 of the API for managing classifications and legacy data classes.   # noqa: E501

    OpenAPI spec version: 2.0.0-unstable
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import collibra_catalog_classification
from collibra_catalog_classification.models.classification_process_response import ClassificationProcessResponse  # noqa: E501
from collibra_catalog_classification.rest import ApiException


class TestClassificationProcessResponse(unittest.TestCase):
    """ClassificationProcessResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testClassificationProcessResponse(self):
        """Test ClassificationProcessResponse"""
        # FIXME: construct object with mandatory attributes with example values
        # model = collibra_catalog_classification.models.classification_process_response.ClassificationProcessResponse()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
